@@ -17,11 +17,21 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifdef __BLOCKS__
+#undef __BLOCKS__
+#endif
+
 #ifndef HS_WEBKIT_H
 #define HS_WEBKIT_H
 /* to avoid stdbool.h error in JavaScriptCore/JSBase.h*/
 #define _Bool int
 
+#define WINAPI
+#define CALLBACK
+
 /* include webkit headers*/
 #include <webkit/webkit.h>
+#include <webkit/webkitdom.h>
 #endif
+
+#include "events.h"
